
Welcome to Solverz Museum!
============================================

Here presents a collection of math models for Solverz simulation.


.. toctree::
   :hidden:

   ae/index.rst
   dae/index.rst
   pde/index.rst
